/*
 *   Copyright 2015, Teo Mrnjavac <teo@kde.org>
 *   Copyright 2015, Matthias Klumpp <mak@debian.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0;
import calamares.slideshow 1.0;

Presentation
{
    id: presentation

    Timer {
        id: advanceTimer
        interval: 12000
        running: false
        repeat: true
        onTriggered: presentation.goToNextSlide()
    }

    Slide {

        Image {
            id: background
            source: "images/background.jpg"
            width: parent.masterWidth
            height: parent.masterHeight
            x: -parent.x
            y: -parent.y
        }

        Image {
            id: icon
            source: "images/desktop.png"
            fillMode: Image.PreserveAspectFit
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.rightMargin: 14
            anchors.bottomMargin: 10
        }

        Text {
            id: title
            font.pointSize: 16
            color: "#ffffff"
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.topMargin: 8
            anchors.leftMargin: 18
            width: parent.width-10
            wrapMode: Text.WordWrap
            font.weight: Font.DemiBold
            text: "Welcome to PureOS!"
        }

        Text {
            id: description
            font.pointSize: 14
            color: "#ffffff"
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.topMargin: 46
            anchors.leftMargin: 18
            width: parent.width-10
            wrapMode: Text.WordWrap
            text: "<p>Thank you for choosing PureOS,<br/>" +
	          " a user friendly, secure and freedom respecting OS for your daily usage.</p>" +
		  "<p>With PureOS, you are the only one in control of your digital life. PureOS is:</p>" +
                  "<ul>" +
                  " <li>Fast and responsive</li>" +
                  " <li>Privacy and security oriented, with freedom by design</li>" +
                  " <li>Based on a solid technological foundation</li>" +
                  " <li>A fully auditable operating system</li>" +
		  " <li>Modern, full-featured and user friendly</li>" +
                  "</ul>" +
                  "<p>Enjoy this release and thank you for choosing PureOS.</p>" +
                  "<p>The installation will take 15-30 minutes,<br/>" +
		  " depending on your hardware and settings.</p>"
        }
    }

    Component.onCompleted: advanceTimer.running = true
}
